@@ -1,9 +1,7 @@
 import pandas as pd
 from time import strptime
 
-
-def get_total_time(effort_data: pd.DataFrame):
-    pass
+from .count_burrows_detection import filter_dates
 
 
 def interval_in_hours(string_time: str):
@@ -12,12 +10,16 @@ def interval_in_hours(string_time: str):
 
 
 def add_duration_in_hours_column(effort_data: pd.DataFrame):
-    effort_data["Duration_hr"] = effort_data.Duracion.apply(interval_in_hours)
+    duration_in_hours = effort_data.Duracion.apply(interval_in_hours)
+    effort_data = effort_data.assign(Duration_hr=duration_in_hours)
     return effort_data
 
 
-def make_summary_of_effort_and_distance(effort_df: pd.DataFrame):
-    column_added = add_duration_in_hours_column(effort_df)
+def make_summary_of_effort_and_distance(
+    effort_df: pd.DataFrame, start_date="2000-01-01", end_date="2100-01-31"
+):
+    filtered_dataframe = filter_dates(effort_df, start_date, end_date)
+    column_added = add_duration_in_hours_column(filtered_dataframe)
     grouped_dataframe = column_added.groupby("Nombre_k9")[["Distancia", "Duration_hr"]].aggregate(
         "sum"
     )
